@@ -48,8 +48,10 @@ class EditingExtension(Extension):
         }
         super(EditingExtension, self).__init__(**kwargs)
 
-    def extendMarkdown(self, md, what):
+    def extendMarkdown(self, md):
         type_map = self.getConfig('type_map')
+        comment_item_processor = CommentItemProcessor(type_map, md)
+        md.inlinePatterns.register(comment_item_processor, 'commentitemedit', 75)
         single_item_processor = SingleItemProcessor(type_map, md)
         md.inlinePatterns.register(single_item_processor, 'singleitemedit', 75)
         dual_item_processor = DualItemProcessor(type_map, md)
@@ -60,10 +62,55 @@ def makeExtension(**kwargs):
     return EditingExtension(**kwargs)
 
 
+class CommentItemProcessor(InlineProcessor):
+    RE = r'''(?x)
+    (?P<item>           # The item block
+    (?P<type>!)\{       # An item
+    (?P<contents> (     # containing
+        (?<=\\)[{}]     #   Any escaped close brace
+        |               #   or
+        [^}]            #   Any non-brace
+    )+)                 #   One or more
+    \}                  # End of item
+    (\(               # Whole attribution block
+    (?P<attribution>    # An attribution of e.g: a name containing
+        [^()]+?         #   one or more non-parens non-greedy
+    )                   # End attribution name
+    (                   # And maybe
+    \ (?P<date>         # A date containing
+    \d\d\d\d-\d\d-\d\d) #   YYYY-MM-DD)
+    )?                  # End maybe
+    \))?                # End of attribution (optional)
+    )                   # End of item block
+    '''
+
+    def __init__(self, type_map, *args, **kwargs):
+        self.type_map = type_map
+        super(CommentItemProcessor, self).__init__(self.RE, *args, **kwargs)
+
+    def handleMatch(self, match, data):
+        el = etree.Element(
+            'q',
+            attrib={'class': self.type_map[match.group('type')]})
+        el.text = match.group('contents')
+        if match.group('attribution') is not None:
+            a = etree.SubElement(
+                el,
+                'span',
+                attrib={'class': self.type_map['a']})
+            a.text = match.group('attribution')
+        if match.group('date') is not None:
+            d = etree.SubElement(
+                el,
+                'span',
+                attrib={'class': self.type_map['d']})
+            d.text = match.group('date')
+        return el, match.start('item'), match.end('item')
+
 class SingleItemProcessor(InlineProcessor):
     RE = r'''(?x)
     (?P<item>           # The item block
-    (?P<type>[-+?!])\{  # An item
+    (?P<type>[-+?])\{  # An item
     (?P<contents> (     # containing
         (?<=\\)[{}]     #   Any escaped close brace
         |               #   or
@@ -82,8 +129,6 @@ class SingleItemProcessor(InlineProcessor):
             tag = 'ins'
         if match.group('type') == '-':
             tag = 'del'
-        if match.group('type') == '!':
-            tag = 'q'
         el = etree.Element(
             tag, 
             attrib={'class': self.type_map[match.group('type')]})
